@@ -14,8 +14,8 @@ Text editor buffer view control for the main notebook
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_editv.py 57710 2009-01-01 23:00:10Z CJP $"
-__revision__ = "$Revision: 57710 $"
+__svnid__ = "$Id: ed_editv.py 58997 2009-02-18 16:00:24Z CJP $"
+__revision__ = "$Revision: 58997 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -41,7 +41,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
     """Tab editor view for main notebook control."""
     DOCMGR = DocPositionMgr()
 
-    def __init__(self, parent, id_, pos=wx.DefaultPosition,
+    def __init__(self, parent, id_=wx.ID_ANY, pos=wx.DefaultPosition,
                  size=wx.DefaultSize, style=0, use_dt=True):
         """Initialize the editor view"""
         ed_stc.EditraStc.__init__(self, parent, id_, pos, size, style, use_dt)
@@ -49,6 +49,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
 
         # Attributes
         self._menu = MakeMenu()
+        self._ignore_del = False
 
         # Initialize the classes position manager for the first control
         # that is created only.
@@ -59,8 +60,25 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         # Context Menu Events
         self.Bind(wx.EVT_CONTEXT_MENU, lambda evt: self.PopupMenu(self._menu))
 
+        # Need to relay the menu events from the context menu to the top level
+        # window to be handled on gtk. Other platforms don't require this.
+        if wx.Platform == '__WXGTK__':
+            self.Bind(wx.EVT_MENU,
+                      lambda evt: wx.PostEvent(self.GetTopLevelParent(), evt))
+
     #---- EdTab Methods ----#
 
+    def DoDeactivateTab(self):
+        """Deactivate any active popups when the tab is no longer
+        the active tab.
+
+        """
+        if self.AutoCompActive():
+            self.AutoCompCancel()
+
+        if self.CallTipActive():
+            self.CallTipCancel()
+
     def DoOnIdle(self):
         """Check if the file has been modified and prompt a warning"""
         if Profile_Get('CHECKMOD'):
@@ -106,6 +124,7 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
 
         menu = ed_menu.EdMenu()
         menu.Append(ed_glob.ID_NEW, _("New Tab"))
+        menu.Append(ed_glob.ID_MOVE_TAB, _("Move Tab to New Window"))
         menu.AppendSeparator()
         menu.Append(ed_glob.ID_SAVE, _("Save \"%s\"") % ptxt)
         menu.Append(ed_glob.ID_CLOSE, _("Close \"%s\"") % ptxt)
@@ -136,6 +155,9 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         @return: bool
 
         """
+        if self._ignore_del:
+            return True
+
         result = True
         if self.GetModify():
             # TODO: Move this method down from the frame to here
@@ -144,6 +166,25 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
 
         return result
 
+    def OnTabMenu(self, evt):
+        """Tab menu event handler"""
+        e_id = evt.GetId()
+        if e_id == ed_glob.ID_COPY_PATH:
+            path = self.GetFileName()
+            if path is not None:
+                util.SetClipboardText(path)
+        elif e_id == ed_glob.ID_MOVE_TAB:
+            t = self.GetTopLevelParent()
+            frame = wx.GetApp().OpenNewWindow()
+            nb = frame.GetNotebook()
+            parent = self.GetParent()
+            pg_txt = parent.GetRawPageText(parent.GetSelection())
+            nb.OpenDocPointer(self.GetDocPointer(), self.GetDocument(), pg_txt)
+            self._ignore_del = True
+            wx.CallAfter(parent.ClosePage)
+        else:
+            evt.Skip()
+
     #---- End EdTab Methods ----#
 
     def PromptToReSave(self, cfile):
