@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 57676 2008-12-30 20:40:41Z CJP $"
-__revision__ = "$Revision: 57676 $"
+__svnid__ = "$Id: ed_glob.py 58981 2009-02-18 05:29:42Z CJP $"
+__revision__ = "$Revision: 58981 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -33,14 +33,16 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_INDENT', 'ID_UNINDENT', 'ID_TO_UPPER', 'ID_TO_LOWER',
             'ID_SPACE_TO_TAB', 'ID_TAB_TO_SPACE', 'ID_TRIM_WS',
             'ID_TOGGLECOMMENT', 'ID_AUTOCOMP', 'ID_AUTOINDENT', 'ID_SYNTAX',
-            'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER', 'ID_KWHELPER',
+            'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER',
             'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 'ID_MACRO_STOP',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
             'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
             'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
             'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER',
-            'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_NEW_WINDOW', 'ID_TOGGLE_FOLD']
+            'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_MAXIMIZE_EDITOR', 
+            'ID_NEW_WINDOW', 'ID_TOGGLE_FOLD', 'ID_TOGGLE_ALL_FOLDS',
+            'ID_FIND_SELECTED']
 
 #---- Project Info ----#
 # The project info was moved to another module so it could be accessed
@@ -126,6 +128,8 @@ ID_FIND          = wx.ID_FIND
 ID_FIND_PREVIOUS = wx.NewId()
 ID_FIND_NEXT     = wx.NewId()
 ID_FIND_REPLACE  = wx.ID_REPLACE
+ID_FIND_SELECTED = wx.NewId()
+
 # Using the system ids automatically disables the menus items
 # when the dialog is open which is not wanted
 if wx.Platform == '__WXMAC__':
@@ -181,8 +185,10 @@ ID_PANELIST      = wx.NewId()
 ID_GOTO_LINE     = wx.NewId()
 ID_GOTO_MBRACE   = wx.NewId()
 ID_TOGGLE_FOLD   = wx.NewId()
+ID_TOGGLE_ALL_FOLDS = wx.NewId()
 ID_NEXT_MARK     = wx.ID_FORWARD
 ID_PRE_MARK      = wx.ID_BACKWARD
+ID_MAXIMIZE_EDITOR = wx.NewId()
 
 # Format Menu IDs
 ID_FONT          = wx.NewId()
@@ -214,7 +220,6 @@ ID_LEXER         = wx.NewId()
 
 # Tool Menu IDs
 ID_COMMAND       = wx.NewId()
-ID_KWHELPER      = wx.NewId()
 ID_PLUGMGR       = wx.NewId()
 ID_STYLE_EDIT    = wx.ID_EDIT
 ID_MACRO_START   = wx.NewId()
@@ -237,6 +242,7 @@ ID_CONTACT       = wx.NewId()
 # Misc IDs
 ID_ADVANCED          = wx.NewId()
 ID_APP_SPLASH        = wx.NewId()
+ID_BACKWARD          = wx.ID_BACKWARD
 ID_BIN_FILE          = ID_COMMAND
 ID_CDROM             = wx.NewId()
 ID_COMMAND_LINE_OPEN = wx.NewId()
@@ -251,9 +257,11 @@ ID_FILE              = wx.ID_FILE
 ID_FIND_RESULTS      = wx.NewId()
 ID_FLOPPY            = wx.NewId()
 ID_FOLDER            = wx.NewId()
+ID_FORWARD           = wx.ID_FORWARD
 ID_HARDDISK          = wx.NewId()
 ID_KEY_PROFILES      = wx.NewId()
 ID_LOGGER            = wx.NewId()
+ID_MOVE_TAB          = wx.NewId()
 ID_PACKAGE           = wx.NewId()
 ID_PYSHELL           = wx.NewId()
 ID_REFRESH           = wx.ID_REFRESH
@@ -308,7 +316,6 @@ ID_2_PROF = {
              ID_PREF_ICONSZ       : 'ICON_SZ',
              ID_PREF_INDENTW      : 'INDENTWIDTH',
              ID_KEY_PROFILES      : 'KEY_PROFILE',
-             ID_KWHELPER          : 'KWHELPER',
              ID_PREF_LANG         : 'LANG',
              ID_PREF_MODE         : 'MODE',
              ID_NEW_WINDOW        : 'OPEN_NW',
