@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 57795 2009-01-02 21:47:50Z CJP $"
-__revision__ = "$Revision: 57795 $"
+__svnid__ = "$Id: ed_main.py 58981 2009-02-18 05:29:42Z CJP $"
+__revision__ = "$Revision: 58981 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -68,9 +68,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         wx.Frame.__init__(self, parent, id_, title, size=wsize,
                           style=wx.DEFAULT_FRAME_STYLE)
 
-        self._mgr = wx.aui.AuiManager(flags=wx.aui.AUI_MGR_DEFAULT | \
-                                      wx.aui.AUI_MGR_TRANSPARENT_DRAG | \
-                                      wx.aui.AUI_MGR_TRANSPARENT_HINT |
+        hint = wx.aui.AUI_MGR_TRANSPARENT_HINT
+        if wx.Platform == '__WXGTK__':
+            # Use venetian blinds style as trasparent can cause crashes
+            # on linux when desktop compositing is used.
+            hint = wx.aui.AUI_MGR_VENETIAN_BLINDS_HINT
+
+        self._mgr = wx.aui.AuiManager(flags=wx.aui.AUI_MGR_DEFAULT |
+                                      wx.aui.AUI_MGR_TRANSPARENT_DRAG |
+                                      hint |
                                       wx.aui.AUI_MGR_ALLOW_ACTIVE_PANE)
         self._mgr.SetManagedWindow(self)
         viewmgr.PerspectiveManager.__init__(self, self._mgr, \
@@ -161,6 +167,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_PASTE_AFTER, self.DispatchToControl),
                                        (ID_COLUMN_MODE, self.DispatchToControl),
                                        (ID_TOGGLE_FOLD, self.DispatchToControl),
+                                       (ID_TOGGLE_ALL_FOLDS, self.DispatchToControl),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -170,6 +177,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_SHOW_SB, self.OnShowStatusBar),
                                        (ID_VIEW_TOOL, self.OnViewTb),
                                        (ID_PANELIST, self.OnPaneList),
+                                       (ID_MAXIMIZE_EDITOR, self.OnMaximizeEditor),
 
                                        # Format Menu
                                        (ID_FONT, self.OnFont),
@@ -231,7 +239,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                                    ID_VIEW_TOOL, ID_SHOW_WS,
                                                    ID_SHOW_EDGE, ID_SHOW_EOL,
                                                    ID_SHOW_LN, ID_INDENT_GUIDES,
-                                                   ]])
+                                                   ID_MAXIMIZE_EDITOR]])
 
         # Lexer Menu
         self._handlers['ui'].extend([(l_id, self.OnUpdateLexerUI)
@@ -276,6 +284,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         ed_msg.PostMessage(ed_msg.EDMSG_DSP_FONT,
                            _PGET('FONT3', 'font', wx.NORMAL_FONT))
 
+        # HACK: for gtk as most linux window managers manage the windows alpha
+        #       and set it when its created.
+        wx.CallAfter(self.InitWindowAlpha)
+
     __name__ = u"MainWindow"
 
     #---- End Private Member Functions/Variables ----#
@@ -288,14 +300,22 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         app = wx.GetApp()
+        active = evt.GetActive()
 
         # Don't needlessly push and pop events if we only have one window open
         if self._loaded and len(app.GetMainWindows()) == 1:
+            if active:
+                wx.UpdateUIEvent.SetUpdateInterval(205)
+                wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
+                self.SetExtraStyle(wx.WS_EX_PROCESS_UI_UPDATES)
+            else:
+                self.SetExtraStyle(0)
+                wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_ALL)
             evt.Skip()
             return
 
         # Add or remove handlers from the event stack
-        if evt.GetActive():
+        if active:
             self._loaded = True
 
             # Slow the update interval to reduce overhead
@@ -310,6 +330,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 app.AddUIHandlerForID(*handler)
 
             app.SetTopWindow(self)
+
+            # HACK find better way to do this later. It seems that on gtk the
+            #      window doesnt get activated until later than it does on the
+            #      other platforms. So for panels that depend on updating their
+            #      initial state we need to send out a fake update message here.
+            if wx.Platform == '__WXGTK__':
+                nb = self.GetNotebook()
+                ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED,
+                                   (nb, nb.GetSelection()))
         else:
             self.SetExtraStyle(0)
 
@@ -472,7 +501,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
             for fname in hist_list:
                 if isinstance(fname, basestring) and fname:
-                    self.filehistory.AddFileToHistory(fname)
+                    # TODO: find out why these errors are happening
+                    #       when loading the pickled strings on some systems
+                    #       The pickled strings are in unicode format.
+                    try:
+                        self.filehistory.AddFileToHistory(fname)
+                    except wx.PyAssertionError:
+                        pass
         except UnicodeEncodeError, msg:
             self.LOG("[ed_main][err] Filehistory load failed: %s" % str(msg))
 
@@ -770,7 +805,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Update profile
         profiler.AddFileHistoryToProfile(self.filehistory)
-        profiler.Profile().Write(_PGET('MYPROFILE'))
+        ppath = _PGET('MYPROFILE')
+        profiler.Profile().Write(ppath)
+        self.LOG("[ed_main][info] Saving profile to %s" % ppath)
 
         # Cleanup file history
         try:
@@ -832,6 +869,20 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
+    def OnMaximizeEditor(self, evt):
+        """Maximize the editor and hide the other panes. If the editor
+        is already maximized, it is un-maximized and the other panes are restored  
+        @param event: CommandEvent instance
+
+        """
+        paneInfo = self._mgr.GetPane("EditPane")
+        if paneInfo.IsMaximized():
+            self._mgr.RestorePane(paneInfo)
+        else:
+            self._mgr.RestoreMaximizedPane()
+            self._mgr.MaximizePane(paneInfo)
+        self._mgr.Update()
+        
     #---- End View Menu Functions ----#
 
     #---- Format Menu Functions ----#
@@ -925,19 +976,21 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wxMenuEvent
 
         """
-        e_id = evt.GetId()
-        if not self.IsActive() and e_id != ID_KWHELPER:
+        if not self.IsActive():
             evt.Skip()
             return
 
+        e_id = evt.GetId()
         ctrl = self.nb.GetCurrentCtrl()
         active_only = [ ID_ZOOM_IN, ID_ZOOM_OUT, ID_ZOOM_NORMAL,
                         ID_JOIN_LINES, ID_CUT_LINE, ID_COPY_LINE, ID_INDENT,
                         ID_UNINDENT, ID_TRANSPOSE, ID_TOGGLECOMMENT,
                         ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
-                        ID_PASTE_AFTER, ID_COLUMN_MODE, ID_TOGGLE_FOLD ]
+                        ID_PASTE_AFTER, ID_COLUMN_MODE, ID_TOGGLE_FOLD,
+                        ID_TOGGLE_ALL_FOLDS ]
 
+        # Special handling for common clipboard related actions
         has_focus = self.FindFocus()
         if has_focus != ctrl and e_id in active_only:
             if has_focus is not None:
@@ -965,7 +1018,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                          ID_AUTOINDENT, ID_TAB_TO_SPACE, ID_SPACE_TO_TAB,
                          ID_TRIM_WS, ID_SHOW_EDGE, ID_MACRO_START,
                          ID_MACRO_STOP, ID_MACRO_PLAY, ID_TO_LOWER,
-                         ID_TO_UPPER, ID_KWHELPER, ID_USE_SOFTTABS,
+                         ID_TO_UPPER, ID_USE_SOFTTABS,
                          ID_GOTO_MBRACE, ID_HLCARET_LINE, ID_REVERT_FILE
                          ])
         menu_ids.extend(active_only)
@@ -1194,6 +1247,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Check(bool(ctrl.GetMarginWidth(1)))
         elif e_id == ID_INDENT_GUIDES:
             evt.Check(bool(ctrl.GetIndentationGuides()))
+        elif e_id == ID_MAXIMIZE_EDITOR:
+            paneInfo = self._mgr.GetPane("EditPane")
+            binder = self.MenuBar.GetKeyBinder()
+            binding = binder.GetBinding(ID_MAXIMIZE_EDITOR)
+            txt = _("Maximize Editor")
+            if paneInfo.IsMaximized():
+                txt = _("Restore Editor")
+            evt.SetText(txt + binding)
         else:
             evt.Skip()
 
