@@ -16,8 +16,8 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 57795 2009-01-02 21:47:50Z CJP $"
-__revision__ = "$Revision: 57795 $"
+__svnid__ = "$Id: ed_search.py 58982 2009-02-18 05:34:12Z CJP $"
+__revision__ = "$Revision: 58982 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -44,12 +44,11 @@ import eclib.finddlg as finddlg
 
 #--------------------------------------------------------------------------#
 # Globals
-RESULT_TEMPLATE = u"%(fname)s (%(lnum)d): %(match)s"
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
 
-class SearchController:
+class SearchController(object):
     """Controls the interface to the text search engine"""
     def __init__(self, owner, getstc):
         """Create the controller
@@ -57,6 +56,8 @@ class SearchController:
         @param getstc: Callable to get the current buffer with
 
         """
+        object.__init__(self)
+
         # Attributes
         self._parent   = owner
         self._stc      = getstc
@@ -67,6 +68,7 @@ class SearchController:
         self._li_sel   = 0
         self._filters  = None
         self._clients = list()
+        self._engine = None
 
         # Event handlers
         self._parent.Bind(finddlg.EVT_FIND, self.OnFind)
@@ -103,6 +105,7 @@ class SearchController:
             if replace is not None and replace.IsOk():
                 dlg.SetReplaceBitmap(replace)
 
+            # Set the persisted data from the last time the dialog was shown
             dlg.SetLookinChoices(self._li_choices)
             dlg.SetLookinSelection(self._li_sel)
             dlg.SetFileFilters(self._filters)
@@ -154,6 +157,13 @@ class SearchController:
         """
         return self._data
 
+    def GetDialog(self):
+        """Return the active find dialog if one exists else return None
+        @return: FindDialog or None
+
+        """
+        return self._finddlg
+
     def GetLastFound(self):
         """Returns the position value of the last found search item
         if the last search resulted in nothing being found then the
@@ -201,6 +211,8 @@ class SearchController:
         isdown = not evt.IsUp()
         engine = SearchEngine(data.GetFindString(), evt.IsRegEx(),
                               isdown, evt.IsMatchCase(), evt.IsWholeWord())
+        engine.SetResultFormatter(FormatResult)
+        self._engine = engine
 
         # Check if expression was valid or not
         if engine.GetQueryObject() is None:
@@ -298,6 +310,7 @@ class SearchController:
         # Create a new search engine object
         engine = SearchEngine(query, evt.IsRegEx(), True,
                               evt.IsMatchCase(), evt.IsWholeWord())
+        engine.SetResultFormatter(FormatResult)
 
         # Send the search function over to any interested parties that wish
         # to process the results.
@@ -322,6 +335,21 @@ class SearchController:
                                (engine.SearchInDirectory,
                                 [path,], dict(recursive=evt.IsRecursive())))
 
+    def OnFindSelected(self, evt):
+        """Set the search query to the selected text and progress the search
+        to the next match.
+
+        """
+        stc = self._stc()
+
+        fstring = stc.GetSelectedText()
+        if fstring:
+            data = self.GetData()
+            data.SetFindString(fstring)
+            self.OnFind(evt)
+        else:
+            evt.Skip()
+
     def OnFindClose(self, evt):
         """Destroy Find Dialog After Cancel is clicked in it
         @param evt: event that called this handler
@@ -364,7 +392,15 @@ class SearchController:
 
         """
         replacestring = evt.GetReplaceString()
-        self._stc().ReplaceSelection(replacestring)
+        if evt.IsRegEx() and self._engine is not None:
+            match = self._engine.GetLastMatch()
+            if match is not None:
+                value = match.expand(replacestring)
+            else:
+                value = replacestring
+        else:
+            value = replacestring
+        self._stc().ReplaceSelection(value)
 
         # Go to the next match
         # Fake event object for on Find Handler
@@ -381,6 +417,8 @@ class SearchController:
         rstring = evt.GetReplaceString()
         engine = SearchEngine(evt.GetFindString(), evt.IsRegEx(),
                               True, evt.IsMatchCase(), evt.IsWholeWord())
+        engine.SetResultFormatter(FormatResult)
+
         results = 0
 
         if smode == finddlg.LOCATION_CURRENT_DOC:
@@ -442,8 +480,8 @@ class SearchController:
                 evt.Skip()
                 return
             self._finddlg.SetTransparent(240)
-            self._finddlg.Show()
 #            self._finddlg.SetExtraStyle(wx.WS_EX_PROCESS_UI_UPDATES)
+            self._finddlg.Show()
         else:
             # Dialog is open already so just update it
             self._UpdateDialogState(eid)
@@ -529,7 +567,7 @@ class SearchController:
 
 #-----------------------------------------------------------------------------#
 
-class SearchEngine:
+class SearchEngine(object):
     """Text Search Engine
     All Search* methods are iterable generators
     All Find* methods do a complete search and return the match collection
@@ -547,6 +585,8 @@ class SearchEngine:
         @keyword wholeword: Match whole word
 
         """
+        object.__init__(self)
+
         # Attributes
         self._isregex = regex
         self._next = down
@@ -556,7 +596,9 @@ class SearchEngine:
         self._query = query
         self._regex = u''
         self._pool = u''
+        self._lmatch = None             # Last match object
         self._filters = None            # File Filters
+        self._formatter = lambda f, l, m: u"%s %d: %s" % (f, l+1, m)
         self._CompileRegex()
 
     def _CompileRegex(self):
@@ -624,7 +666,7 @@ class SearchEngine:
 
         for lnum, line in enumerate(StringIO(self._pool)):
             if self._regex.search(line) is not None:
-                rlist.append(FormatResult(_("Untitled"), lnum, line))
+                rlist.append(self._formatter(_("Untitled"), lnum, line))
 
         return rlist
 
@@ -642,6 +684,7 @@ class SearchEngine:
         if spos < len(self._pool):
             match = self._regex.search(self._pool[spos:])
             if match is not None:
+                self._lmatch = match
                 return match.span()
         return None
 
@@ -659,9 +702,18 @@ class SearchEngine:
             matches = [match for match in self._regex.finditer(self._pool[:spos])]
             if len(matches):
                 lmatch = matches[-1]
+                self._lmatch = lmatch
                 return (lmatch.start(), lmatch.end())
         return None
 
+    def GetLastMatch(self):
+        """Get the last found match object from the previous L{FindNext} or
+        L{FindPrev} action.
+        @return: match object or None
+
+        """
+        return self._lmatch
+
     def GetOptionsString(self):
         """Get a string describing the search engines options"""
         rstring = u"\"%s\" [ " % self._query
@@ -786,7 +838,7 @@ class SearchEngine:
 
             for lnum, line in enumerate(fobj):
                 if self._regex.search(line) is not None:
-                    yield FormatResult(fname, lnum, line)
+                    yield self._formatter(fname, lnum, line)
             fobj.close()
         return
 
@@ -834,6 +886,14 @@ class SearchEngine:
                 setattr(self, attr, val)
         self._CompileRegex()
 
+    def SetResultFormatter(self, funct):
+        """Set the result formatter function
+        @param funct: callable(filename, linenum, matchstr)
+
+        """
+        assert callable(funct)
+        self._formatter = funct
+
     def SetSearchPool(self, pool):
         """Set the search pool used by the Find methods
         @param pool: string to search in
@@ -870,7 +930,9 @@ def FormatResult(fname, lnum, match):
         match = _("DECODING ERROR")
     else:
         match = u" " + match.lstrip()
-    return RESULT_TEMPLATE % dict(fname=fname, lnum=lnum+1, match=match)
+
+    rstring = u"%(fname)s (%(lnum)d): %(match)s"
+    return rstring % dict(fname=fname, lnum=lnum+1, match=match)
 
 #-----------------------------------------------------------------------------#
 
