@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 57765 2009-01-02 04:57:26Z CJP $"
-__revision__ = "$Revision: 57765 $"
+__svnid__ = "$Id: ed_stc.py 58981 2009-02-18 05:29:42Z CJP $"
+__revision__ = "$Revision: 58981 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -158,18 +158,16 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
+        self.Bind(wx.stc.EVT_STC_CHANGE, self.OnChanged)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
         self.Bind(wx.stc.EVT_STC_UPDATEUI, self.OnUpdateUI)
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
         self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
-        
-        # Need to relay the menu events from the context menu to the top level
-        # window to be handled on gtk. Other platforms don't require this.
-        if wx.Platform == '__WXGTK__':
-            self.Bind(wx.EVT_MENU,
-                      lambda evt: wx.PostEvent(self.GetTopLevelParent(), evt))
+
+        # Async file load events
+        self.Bind(ed_txt.EVT_FILE_LOAD, self.OnLoadProgress)
 
        #---- End Init ----#
 
@@ -237,8 +235,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 txt = self.GetLine(line)
                 diff = len(txt.rstrip())
                 self.GotoPos(pos + diff)
+                if shift_down:
+                    self.SetSelection(pos, pos + diff)
             elif k_code == wx.WXK_LEFT:
+                cpos = self.GetCurrentPos()
                 self.GotoIndentPos(line)
+                if shift_down:
+                    self.SetSelection(cpos, self.GetCurrentPos())
             else:
                 return False
         else:
@@ -372,7 +375,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def GetBracePair(self):
         """Get a tuple of the positions in the buffer where the brace at the
-        current caret position and its match are. if a brace doesn't have a 
+        current caret position and its match are. if a brace doesn't have a
         match it will return -1 for the missing brace.
         @return: tuple (brace_at_caret, brace_opposite)
 
@@ -425,6 +428,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.ToggleLineNumbers(_PGET('SHOW_LN'))
         self.SetViEmulationMode(_PGET('VI_EMU'))
         self.SetViewEdgeGuide(_PGET('SHOW_EDGE'))
+        # NOTE: disabled because it is more annoying than it is benificial.
+#        self.SetEndAtLastLine(False)
 
     def Comment(self, start, end, uncomment=False):
         """(Un)Comments a line or a selected block of text
@@ -725,8 +730,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def FireModified(self):
         """Fire a modifed event"""
-        self.OnModified(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_MODIFIED,
-                                               self.GetId()))
+        self.OnChanged(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_CHANGE,
+                                              self.GetId()))
 
     def GetAutoComplete(self):
         """Is Autocomplete being used by this instance
@@ -765,7 +770,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         if self.key_handler.PreProcessKey(k_code, ctrl_down,
                                           cmd_down, shift_down, alt_down):
-            return                
+            return
 
         if wx.Platform == '__WXMAC__' and \
            self._MacHandleKey(k_code, shift_down, alt_down, ctrl_down, cmd_down):
@@ -783,6 +788,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             if self.CallTipActive():
                 self.CallTipCancel()
 
+        elif self.vert_edit.Enabled:
+            # XXX: handle column mode
+            self.vert_edit.OnKeyDown(evt)
         else:
             evt.Skip()
 
@@ -813,8 +821,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         elif key_code in self._code['compsvc'].GetAutoCompKeys():
             if self.AutoCompActive():
                 self.AutoCompCancel()
+
             if self.CallTipActive():
                 self.CallTipCancel()
+
             command = self.GetCommandStr() + unichr(key_code)
             self.AddText(unichr(key_code))
             if self._config['autocomp']:
@@ -823,6 +833,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         elif self._code['compsvc'].IsAutoCompEvent(evt):
             if self.AutoCompActive():
                 self.AutoCompCancel()
+
             command = self.GetCommandStr()
             if self._config['autocomp']:
                 self.ShowAutoCompOpt(command)
@@ -848,7 +859,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 self.CallTipCancel()
         else:
             evt.Skip()
-        return
 
     def OnKeyUp(self, evt):
         """Update status bar of window
@@ -951,10 +961,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @param command: command to look for autocomp options for
 
         """
+        pos = self.GetCurrentPos()
         lst = self._code['compsvc'].GetAutoCompList(command)
         if len(lst):
-            pos = self.GetCurrentPos()
+            self.BeginUndoAction()
             self.AutoCompShow(pos - self.WordStartPosition(pos, True), u' '.join(lst))
+
+            if len(lst) == 1 and self._code['compsvc'].GetAutoCompAfter():
+                super(EditraStc, self).GotoPos(pos)
+            self.EndUndoAction()
             self.SetFocus()
 
     def ShowCallTip(self, command):
@@ -972,22 +987,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             fail_safe = curr_pos - self.GetColumn(curr_pos)
             self.CallTipShow(max(tip_pos, fail_safe), tip)
 
-    def ShowKeywordHelp(self):
-        """Displays the keyword helper
-        @postcondition: keyword helper list is shown if it currently is not
-                        otherwise it is hidden.
-
-        """
-        if self.AutoCompActive():
-            self.AutoCompCancel()
-        elif len(self._code['keywords']) > 1:
-            pos = self.GetCurrentPos()
-            pos2 = self.WordStartPosition(pos, True)
-            self.AutoCompShow(pos - pos2, self._code['keywords'])
-        return
-
     def OnLeftUp(self, evt):
-        """Set primary selection and inform mainwindow that cursor position 
+        """Set primary selection and inform mainwindow that cursor position
         has changed.
         @param evt: wx.MouseEvent()
 
@@ -1001,7 +1002,14 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 #            util.SetClipboardText(stxt, primary=True)
         self.PostPositionEvent()
 
-    def OnModified(self, evt):
+    def OnLoadProgress(self, evt):
+        """Recieves file loading events from asynchronous file loading"""
+        if evt.HasText():
+            self.SetReadOnly(False)
+            #self.AppendText(evt.GetValue())
+            self.SetReadOnly(True)
+
+    def OnChanged(self, evt):
         """Handles updates that need to take place after
         the control has been modified.
         @param evt: event that called this handler
@@ -1022,8 +1030,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if self.GetMarginWidth(NUM_MARGIN) != nwidth:
             self.SetMarginWidth(NUM_MARGIN, nwidth)
 
-        self.vert_edit.OnModified(evt)
         wx.PostEvent(self.GetParent(), evt)
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_CHANGED)
+
+    def OnModified(self, evt):
+        """Handle modify events, includes style changes!"""
+        if self.vert_edit.Enabled:
+            self.vert_edit.OnModified(evt)
+        else:
+            evt.Skip()
 
     def OnUpdateUI(self, evt):
         """Check for matching braces
@@ -1032,16 +1047,18 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         # If disabled just skip the event
-        if not self._config['brackethl']:
-            evt.Skip()
-            return
+        if self._config['brackethl']:
+            brace_at_caret, brace_opposite = self.GetBracePair()
+            # CallAfter necessary to reduce CG warnings on Mac
+            if brace_at_caret != -1  and brace_opposite == -1:
+                wx.CallAfter(self.BraceBadLight, brace_at_caret)
+            else:
+                wx.CallAfter(self.BraceHighlight, brace_at_caret, brace_opposite)
 
-        brace_at_caret, brace_opposite = self.GetBracePair()
-        # CallAfter necessary to reduce CG warnings on Mac
-        if brace_at_caret != -1  and brace_opposite == -1:
-            wx.CallAfter(self.BraceBadLight, brace_at_caret)
-        else:
-            wx.CallAfter(self.BraceHighlight, brace_at_caret, brace_opposite)
+        # XXX: handle when column mode is enabled
+        if self.vert_edit.Enabled:
+            self.vert_edit.OnUpdateUI(evt)
+        evt.Skip()
 
     def OnMarginClick(self, evt):
         """Open and Close Folders as Needed
@@ -1109,12 +1126,12 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 if expanding:
                     self.SetFoldExpanded(line_num, True)
                     line_num = self.Expand(line_num, True) - 1
-            else:
-                last_child = self.GetLastChild(line_num, -1)
-                self.SetFoldExpanded(line_num, False)
+                else:
+                    last_child = self.GetLastChild(line_num, -1)
+                    self.SetFoldExpanded(line_num, False)
 
-                if last_child > line_num:
-                    self.HideLines(line_num + 1, last_child)
+                    if last_child > line_num:
+                        self.HideLines(line_num + 1, last_child)
             line_num = line_num + 1
 
     def Expand(self, line, do_expand, force=False, vis_levels=0, level=-1):
@@ -1207,7 +1224,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_PASTE : self.Paste, ed_glob.ID_UNDO : self.Undo,
                   ed_glob.ID_REDO  : self.Redo, ed_glob.ID_INDENT : self.Tab,
                   ed_glob.ID_REVERT_FILE : self.RevertToSaved,
-                  ed_glob.ID_KWHELPER: self.ShowKeywordHelp,
                   ed_glob.ID_CUT_LINE : self.LineCut,
                   ed_glob.ID_COLUMN_MODE : self.ToggleColumnMode,
                   ed_glob.ID_COPY_LINE : self.LineCopy,
@@ -1223,6 +1239,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_AUTOINDENT : self.ToggleAutoIndent,
                   ed_glob.ID_LINE_AFTER : self.AddLine,
                   ed_glob.ID_TOGGLE_FOLD : self.ToggleFold,
+                  ed_glob.ID_TOGGLE_ALL_FOLDS : self.FoldAll,
                   ed_glob.ID_TRIM_WS : self.TrimWhitespace,
                   ed_glob.ID_MACRO_START : self.StartRecord,
                   ed_glob.ID_MACRO_STOP : self.StopRecord,
@@ -1424,6 +1441,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             return u' ' * self.GetIndent()
 
+    def GetKeywords(self):
+        """Get the keyword set for the current document.
+        @return: list of strings
+
+        """
+        return self._code['keywords']
+
     def GetEOLModeId(self):
         """Gets the id of the eol format. Convinience for updating
         menu ui.
@@ -1457,6 +1481,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @return: bool
 
         """
+        pos = max(0, pos-1)
         return 'comment' in self.FindTagById(self.GetStyleAt(pos))
 
     def IsFoldingOn(self):
@@ -1664,10 +1689,17 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Begin stripping trailing whitespace
         self.BeginUndoAction()
-        for line in xrange(self.GetLineCount() + 1):
+        for line in xrange(self.GetLineCount()):
             eol = u''
             tmp = self.GetLine(line)
-            tlen = len(tmp)
+
+            # Scintilla stores text in utf8 internally so we need to
+            # encode to utf8 to get the correct length of the text.
+            try:
+                tlen = len(tmp.encode('utf-8'))
+            except:
+                tlen = len(tmp)
+
             if tlen:
                 if "\r\n" in tmp:
                     eol = "\r\n"
@@ -2083,7 +2115,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.SetStyleBits(7)
         elif lexer == wx.stc.STC_LEX_NULL:
             self.SetStyleBits(5)
-            self.SetIndentationGuides(False)
             self.SetLexer(lexer)
             self.ClearDocumentStyle()
             self.UpdateBaseStyles()
@@ -2156,7 +2187,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         # Parse Keyword Settings List simply ignoring bad values and badly
         # formed lists
-        self._code['keywords'] = ""
+        self._code['keywords'] = list()
+        kwlist = ""
         for keyw in kw_lst:
             if len(keyw) != 2:
                 continue
@@ -2165,18 +2197,17 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                    not isinstance(keyw[1], basestring):
                     continue
                 else:
-                    self._code['keywords'] += keyw[1]
+                    kwlist += keyw[1]
                     super(EditraStc, self).SetKeyWords(keyw[0], keyw[1])
 
-        kwlist = self._code['keywords'].split()    # Split into a list of words
-        kwlist = list(set(kwlist))                 # Uniqueify the list
-        kwlist.sort()                              # Sort into alphbetical order
+        kwlist = kwlist.split()         # Split into a list of words
+        kwlist = list(set(kwlist))      # Uniqueify the list
+        kwlist.sort()                   # Sort into alphbetical order
 
         # Can't have ? in scintilla autocomp list unless specifying an image
         if '?' in kwlist:
             kwlist.remove('?')
-        self._code['keywords'] = " ".join(kwlist)  # Put back into a string
-        return True
+        self._code['keywords'] = kwlist
 
     def SetProperties(self, prop_lst):
         """Sets the Lexer Properties from a list of specifications
@@ -2237,9 +2268,9 @@ def _GetMacKeyBindings():
     # A good reference for these: http://www.yellowbrain.com/stc/keymap.html
     return [
             # Move/select/delete by word
-            (wx.stc.STC_KEY_LEFT, wx.stc.STC_SCMOD_ALT, 
+            (wx.stc.STC_KEY_LEFT, wx.stc.STC_SCMOD_ALT,
              wx.stc.STC_CMD_WORDLEFT),
-            (wx.stc.STC_KEY_RIGHT, wx.stc.STC_SCMOD_ALT, 
+            (wx.stc.STC_KEY_RIGHT, wx.stc.STC_SCMOD_ALT,
              wx.stc.STC_CMD_WORDRIGHT),
             (wx.stc.STC_KEY_LEFT, ALT_SHIFT, wx.stc.STC_CMD_WORDLEFTEXTEND),
             (wx.stc.STC_KEY_RIGHT, ALT_SHIFT, wx.stc.STC_CMD_WORDRIGHTEXTEND),
@@ -2249,7 +2280,7 @@ def _GetMacKeyBindings():
              wx.stc.STC_CMD_DELWORDRIGHT),
             (wx.stc.STC_KEY_BACK, ALT_SHIFT, wx.stc.STC_CMD_DELWORDRIGHT),
             (wx.stc.STC_KEY_DELETE, ALT_SHIFT, wx.stc.STC_CMD_DELWORDLEFT),
-            
+
             # Move/select/delete by line
             (wx.stc.STC_KEY_LEFT, wx.stc.STC_SCMOD_CTRL,
              wx.stc.STC_CMD_VCHOME),
@@ -2263,16 +2294,16 @@ def _GetMacKeyBindings():
              wx.stc.STC_CMD_DELLINERIGHT),
             (wx.stc.STC_KEY_BACK, CTRL_SHIFT, wx.stc.STC_CMD_DELLINERIGHT),
             (wx.stc.STC_KEY_DELETE, CTRL_SHIFT, wx.stc.STC_CMD_DELLINELEFT),
-            
+
             # By-character deletion behavior
             (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_NORM,
              wx.stc.STC_CMD_DELETEBACK),
             (wx.stc.STC_KEY_DELETE, wx.stc.STC_SCMOD_SHIFT,
              wx.stc.STC_CMD_DELETEBACK),
 
-            # NOTE: The following two are a special case, since Scintilla 
+            # NOTE: The following two are a special case, since Scintilla
             # doesn't have a forward-delete action.  So here we just cancel any
-            # tip our auto-completion display, and then implement forward 
+            # tip our auto-completion display, and then implement forward
             # delete in OnKeyDown.
             #(wx.stc.STC_KEY_DELETE, 0, wx.stc.STC_CMD_CANCEL),
             (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_SHIFT,
