@@ -12,22 +12,25 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 57765 2009-01-02 04:57:26Z CJP $"
-__revision__ = "$Revision: 57765 $"
+__svnid__ = "$Id: ed_txt.py 58682 2009-02-05 18:17:34Z CJP $"
+__revision__ = "$Revision: 58682 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
 import sys
 import re
+import wx
+import threading
 import codecs
 import locale
 import types
 from StringIO import StringIO
 
 # Local Imports
-from util import Log, GetFileModTime
+from util import Log, GetFileModTime, GetFileSize
 from profiler import Profile_Get
+import ed_msg
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -149,7 +152,7 @@ class EdFile(object):
         if len(remove):
             remove.reverse()
             for idx in remove:
-                list.pop(idx)
+                self._mcallback.pop(idx)
 
     def GetEncoding(self):
         """Get the encoding used by the file it may not be the
@@ -222,7 +225,7 @@ class EdFile(object):
         """File modification time propery"""
         return self.GetModtime()
 
-    def Read(self):
+    def Read(self, store=None, chunk=512):
         """Get the contents of the file as a string, automatically handling
         any decoding that may be needed.
 
@@ -249,7 +252,15 @@ class EdFile(object):
 
             try:
                 reader = codecs.getreader(self.encoding)(self._handle)
-                txt = reader.read()
+                txt = u''
+                if store is None:
+                    while 1:
+                        tmp = reader.read(chunk)
+                        if not len(tmp):
+                            break
+                        txt += tmp
+                else:
+                    store(reader, chunk)
                 reader.close()
             except Exception, msg:
                 Log("[ed_txt][err] Error while reading with %s" % self.encoding)
@@ -274,6 +285,31 @@ class EdFile(object):
         else:
             raise ReadError, self.last_err
 
+    def ReadAsync(self, control):
+        """Read the file asynchronously on a separate thread
+        @param control: text control to send text to
+
+        """
+        pid = control.GetTopLevelParent().GetId()
+        filesize = GetFileSize(self.path)
+        ed_msg.PostMessage(ed_msg.EDMSG_PROGRESS_SHOW, (pid, True))
+        ed_msg.PostMessage(ed_msg.EDMSG_PROGRESS_STATE, (pid, 0, filesize))
+
+        def generator(reader, chunk):
+            """Read generator"""
+            counter = 0
+            while 1:
+                txt = reader.read(chunk * 1024)
+                if not len(txt):
+                    break
+
+                ed_msg.PostMessage(ed_msg.EDMSG_PROGRESS_STATE,
+                                   (pid, (chunk * 1024) * counter, filesize))
+                counter += 1
+                yield txt
+        thread = FileReadThread(control, self.Read, generator)
+        thread.start()
+
     @property
     def ReadOnly(self):
         return self.IsReadOnly()
@@ -357,6 +393,63 @@ class EdFile(object):
         else:
             raise WriteError, self.last_err
 
+#-----------------------------------------------------------------------------#
+
+class FileReadThread(threading.Thread):
+    """Worker thread for reading text from a file"""
+    def __init__(self, reciever, task, *args, **kwargs):
+        """Create the thread
+        @param reciever: Window to recieve events
+        @param task: generator method to call
+
+        """
+        threading.Thread.__init__(self)
+        self.cancel = False
+        self._task = task
+        self.reciever = reciever
+        self._args = args
+        self._kwargs = kwargs
+
+    def run(self):
+        """Read the text"""
+        for txt in self._task(*self._args, **self._kwargs):
+            if self.cancel:
+                break
+
+            evt = FileLoadEvent(edEVT_FILE_LOAD, wx.ID_ANY, txt)
+            wx.PostEvent(self.reciever, evt)
+
+    def Cancel(self):
+        """Cancel the running task"""
+        self.cancel = True
+
+#-----------------------------------------------------------------------------#
+
+edEVT_FILE_LOAD = wx.NewEventType()
+EVT_FILE_LOAD = wx.PyEventBinder(edEVT_FILE_LOAD, 1)
+class FileLoadEvent(wx.PyEvent):
+    """Event to signal that a chunk of text haes been read"""
+    def __init__(self, etype, eid, value=None):
+        """Creates the event object"""
+        wx.PyEvent.__init__(self, eid, etype)
+
+        # Attributes
+        self._value = value
+    
+    def HasText(self):
+        """Returns true if the event has text
+        @return: bool whether the event contains text
+
+        """
+        return self._value is not None
+
+    def GetValue(self):
+        """Returns the value from the event.
+        @return: the value of this event
+
+        """
+        return self._value
+
 #-----------------------------------------------------------------------------#
 # Utility Function
 def CheckBom(line):
