@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 57476 2008-12-21 17:18:35Z CJP $"
-__revision__ = "$Revision: 57476 $"
+__svnid__ = "$Id: profiler.py 58360 2009-01-24 19:33:08Z CJP $"
+__revision__ = "$Revision: 58360 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -232,7 +232,7 @@ class Profile(dict):
             cPickle.dump(self.copy(), fhandle, cPickle.HIGHEST_PROTOCOL)
             fhandle.close()
         except (IOError, cPickle.PickleError), msg:
-            dev_tool.DEBUGP("[profile][err] %s" % str(msg))
+            dev_tool.DEBUGP(u"[profile][err] %s" % msg)
             return False
         else:
             return True
