@@ -6,9 +6,14 @@
 # License: wxWindows License                                                  #
 ###############################################################################
 
+"""Unittest cases for testing the various Utility functions in
+the util module.
+
+"""
+
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testUtil.py 57492 2008-12-22 00:48:12Z CJP $"
-__revision__ = "$Revision: 57492 $"
+__svnid__ = "$Id: testUtil.py 59010 2009-02-19 03:53:56Z CJP $"
+__revision__ = "$Revision: 59010 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
